/* wstar.js

WSTAR, my pet application
Written by Pintér Gábor
Feuerwehrgasse 1/2/9
Purbach am Neusiedlersee
A-7083, Austria
Tel: +43 670 2055090
Email: pinter.gabor@gmx.at
Web: https://pintergabor.eu

Revisions:
  V1.0  2014-03-20  Ported to JavaScript, HTML5
  V1.1  2014-09-16  Create with id string
  V1.2  2020-01-07  https, and other minor changes

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 3
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

https://www.gnu.org/copyleft/gpl.html

For commercial license, and for other professional
JavaScript and Java components please contact the author.


Example: https://pintergabor.eu/en/www/wstar/

*/

// Construct with defaults and link it to a canvas
function wstar(canvas) {

	// Advertisement
	canvas.onclick= function() {
		window.location.href= "https://pintergabor.eu/en/www/wstar/";
	}

	// Defaults
	if (typeof(canvas) === "string") {
		canvas= document.getElementById(canvas);
	}
	this.canvas= canvas;
	this.points= 19;
	this.center= { x:canvas.width/2, y:canvas.height/2 };
	this.radius= Math.min(this.center.x, this.center.y);
	this.backcolor= "white";
	this.color= "random";

	// Clear canvas
	this.clear= function() {
		var ctx= this.canvas.getContext("2d");
		ctx.fillStyle= this.backcolor;
		ctx.fillRect(0, 0, this.canvas.width, this.canvas.height);
	}

	// Draw the image
	this.draw= function() {
		var ctx= this.canvas.getContext("2d");
		// Calculate points
		var p= [];
		var i, j;
		for (i= 0; i < this.points; i++) {
			p.push( {
				x: Math.round(this.center.x+this.radius*Math.sin(2*Math.PI*i/this.points)),
				y: Math.round(this.center.y+this.radius*Math.cos(2*Math.PI*i/this.points))
			} );
		}
		// Draw
		for (i= 1; i <= this.points/2; i++) {
			var color= this.color == "random" ?
				"rgb(" +
					Math.round(256*Math.random()) + "," +
					Math.round(256*Math.random()) + "," +
					Math.round(256*Math.random()) + ")" :
				this.color;
			for (j= 0; j < this.points; j++) {
				ctx.beginPath();
				ctx.moveTo(p[j].x, p[j].y);
				ctx.lineTo(p[(i+j)%this.points].x, p[(i+j)%this.points].y);
				ctx.strokeStyle= color;
				ctx.stroke();
			}
		}
	}
}

